import { LinkTopic } from '../../components/LinkTopic';
import { HelpTopic } from '../../models/helpTopic';

function HelpConceptSynthesis() {
  return (
    <div className='text-justify'>
      <h1>Синтез концептуальных схем</h1>
      <p>
        Работа с крупными предметными областями требуют рассмотрения различных точек зрения в рамках одной предметной
        области, то есть формирования ряда раздельных концептуальных схем. При этом ключевые понятия для выработки
        решений требуют комбинирования выразительных способностей этих схем.
      </p>

      <p>
        Решением этой задачи является введение формальной операции <b>синтеза концептуальных схем</b>. Полученная в
        результате операции концептуальная схема синтезе должна объединять выразительные способности исходных схем, а
        также содержать понятия, не выразимые в исходных схемах по отдельности.
      </p>

      <p>
        Расширение выразительной способности достигается несколькими способами в зависимости от соотношения
        синтезируемых точек зрения:
        <li>
          <b>аспектный синтез</b> характеризуется отождествлением общих понятий в случае, когда часть неопределяемых
          понятий является общей для двух точек зрения;
        </li>
        <li>
          <b>конкретизирующий синтез</b> заменяет неопределяемое слабо ограниченное понятия из одной схемы на более
          ограниченное, конкретное базовое или производное понятие из другой схемы;
        </li>
        <li>
          <b>синтез через новое новое отношение</b> помимо исходных схем использует абстрактную (не имеющую предметной
          интерпретации) схему для соединения понятий из двух операндов путем введения нового неопределяемого понятия,
          моделирующего отношения между синтезируемыми схемами.
        </li>
      </p>
      <p>
        Возможно использование комбинации описанных подходов в рамках одного синтеза. Более подробно про реализацию
        операций в родоструктурной форме можно прочитать в{' '}
        <LinkTopic text='разделе Операции' topic={HelpTopic.RSL_OPERATIONS} />
      </p>
      <p>
        Для управления совокупностью синтезов используются{' '}
        <LinkTopic text='операционные схемы синтеза' topic={HelpTopic.CC_OSS} />.
      </p>
    </div>
  );
}

export default HelpConceptSynthesis;
